isItemEnabled property

bool Function(T item)? isItemEnabled
final

Callback to determine if an item can be selected Returns true if the item is enabled, false if disabled Disabled items will appear grayed out and cannot be selected

Implementation

final bool Function(T item)? isItemEnabled;