ScopingLinesGuide class
Indent guide that draws vertical scoping lines.
- Inheritance
-
- Object
- IndentGuide
- AbstractLinesGuide
- ScopingLinesGuide
Constructors
- ScopingLinesGuide({double indent = 40.0, EdgeInsetsGeometry padding = EdgeInsets.zero, int maxLevel = largestPositiveInteger, Color color = const Color(0xFF424242), double thickness = 2.0, double origin = 0.5, StrokeCap strokeCap = StrokeCap.butt, StrokeJoin strokeJoin = StrokeJoin.miter, PathModifier? pathModifier})
-
const
Properties
- color → Color
-
Color of the lines.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- indent → double
-
Amount of indent per level.
finalinherited
- maxLevel → int
-
Maximum indentation level.
finalinherited
- origin → double
-
Horizontal origin point (0.0 = left, 1.0 = right).
finalinherited
- padding → EdgeInsetsGeometry
-
Padding around the child widget.
finalinherited
- pathModifier → PathModifier?
-
Optional path modifier.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeCap → StrokeCap
-
Stroke cap style.
finalinherited
- strokeJoin → StrokeJoin
-
Stroke join style.
finalinherited
- thickness → double
-
Thickness of the lines.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size, TreeEntry< Object> entry, double indent) → void -
Paints the guide lines.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
wrap(
BuildContext context, Widget child, TreeEntry< Object> entry) → Widget -
Wraps
childwith indentation and decoration.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited