SliverTree<T extends Object> class
A sliver that displays a tree structure.
This widget creates a flat representation of the tree and renders it using SliverList for efficient lazy loading.
Example:
CustomScrollView(
slivers: [
SliverTree<Node>(
controller: treeController,
nodeBuilder: (context, entry) {
return ListTile(title: Text(entry.node.title));
},
),
],
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SliverTree
- Implementers
Constructors
-
SliverTree({Key? key, required TreeController<
T> controller, required TreeNodeBuilder<T> nodeBuilder, bool enableCheckbox = false, bool enableSelectAll = false, String labelSelectAll = 'Select All', String labelClearAll = 'Clear All', String labelSelected = 'Selected'}) -
const
Properties
-
controller
→ TreeController<
T> -
The controller managing the tree state.
final
- enableCheckbox → bool
-
Whether to enable checkbox selection.
final
- enableSelectAll → bool
-
Whether to enable Select All/Unselect All button.
Only works when enableCheckbox is true.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelClearAll → String
-
final
- labelSelectAll → String
-
final
- labelSelected → String
-
final
-
nodeBuilder
→ TreeNodeBuilder<
T> -
Builder for creating widgets from tree entries.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SliverTree< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited