TreeDragAndDropDetails<T extends Object> class
Details of a drag-and-drop operation.
Constructors
-
TreeDragAndDropDetails({required T draggedNode, required T targetNode, required Offset dropPosition, required Rect targetBounds, List<
T?> candidateData = const [], List rejectedData = const []}) -
const
Properties
-
candidateData
→ List<
T?> -
Candidate drag data.
final
- draggedNode → T
-
The node being dragged.
final
- dropPosition → Offset
-
Position where drag is hovering within target bounds.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rejectedData → List
-
Rejected drag data.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetBounds → Rect
-
Bounding box of the target widget.
final
- targetNode → T
-
The target node.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited